﻿# Création des fonctions

Function Get-FSMORoleOwner {  
<#    
.SYNOPSIS    
    Récupère les rôles FSMO de la forêt et des domaines     
  
.EXAMPLE  
    Get-FSMORoleOwner          
#>  
[cmdletbinding()]   
Param() 
Try {  
    $forest = [system.directoryservices.activedirectory.Forest]::GetCurrentForest()   
    ForEach ($domain in $forest.domains) {  
        $forestproperties = @{  
            Forest = $Forest.name  
            Domain = $domain.name  
            SchemaRole = $forest.SchemaRoleOwner  
            NamingRole = $forest.NamingRoleOwner  
            RidRole = $Domain.RidRoleOwner  
            PdcRole = $Domain.PdcRoleOwner  
            InfrastructureRole = $Domain.InfrastructureRoleOwner  
            }  
        $newobject = New-Object PSObject -Property $forestproperties  
        $newobject.PSTypeNames.Insert(0,"ForestRoles")  
        $newobject  
        }  
    }  
Catch {  
    Write-Warning "$($Error)"  
    }  
}

# Fonction Get-GPO

function Get-GPO 
 {
    param ($domain = $(throw 'Veuillez préciser le nom du domaine au format DNS'))

   $gpm = New-Object -ComObject GPMgmt.GPM
    $gpmConstants = $gpm.GetConstants() 
    $gpmDomain = $gpm.GetDomain($domain, '', $gpmConstants.UseAnyDC)
    $gpmSearchCriteria = $gpm.CreateSearchCriteria()
    $gpmAllGpos = $gpmDomain.SearchGPOs($gpmSearchCriteria)
  
    $pathdir = new-item -path c:\temp -name "Rapports GPOs" -type directory -force

    $gpmAllGpos|foreach{
        $_.GenerateReportToFile($gpmconstants.ReportHTML,$pathdir.get_fullname()+"\"+$_.displayname+".html")
    }
 }


# Fonction Show-MessageBox

function Show-MessageBox([string] $Message="Merci de nous faire parvenir le fichier zipper 'c:\rapport\Rapport sur le domaine audite.zip'. Supprimez le fichier de votre disque dur à l'issue ainsi que le dossier nommé du nom de votre domaine. Merci!",[string] $Titre="Fin de l'analyse",  [String] $IconType="Information",[String] $BtnType="Ok")
{  #Affiche une boîte de dialogue fenêtrée
   #Prérequis [void][Reflection.Assembly]::LoadWithPartialName("System.Windows.Forms")

  trap 
  {
   switch ($_.Exception.GetType().FullName) 
   {
    "System.Management.Automation.PSInvalidCastException" {$_.message;Break}
    "System.Management.Automation.RuntimeException" {
     Throw "Assurez-vous que l'assembly [System.Windows.Forms] est bien chargé."}
    default {Throw $_}
    }#switch
  }#trap
  return [Windows.Forms.MessageBox]::Show($Message,$Titre, $BtnType,$IconType)
}
# Scan-Ports.msh   
#  
# Scanne les ordinnateurs et vérifie les ports ouverts
#   

if (!(get-command -ea SilentlyContinue new)) {set-alias new New-Object} 

# Exemples d'utilisation : 

#Scan-Ports mail 110 
#$server = "mail" 
#$ports = 21,25,23,80,110,8080,4444 + 130..140 
#$ports = @(110) 
#Scan-Ports $server $ports 

# Fonction Scan-Ports

Function Scan-Ports { 
  param ($server = "localhost",[int[]]$ports)
  &{ 
    trap{"Server $Server not Found";continue} 
    $ping = new Net.NetworkInformation.Ping 
    $script:result = $null 
    $script:result = $ping.send($server) 
  } 
  if ($result) { 
    foreach ($port in $ports) { 
      Trap {"$port non ouvert";continue} 
      "Checking $server $port :" 
      $client = new net.sockets.tcpclient 
      $client.connect($server,$port) 
      if ($client.connected) { 
        "Le port $port est ouvert" 
        $stream = $client.GetStream() 
        $chars = @() 
        sleep -m 1000 # Give server some time to react  
        while ($stream.DataAvailable) {$chars += [char]$stream.readByte()} 
        #([System.Text.ASCIIEncoding]::utf8).GetChars([byte[]]$chars) 
        [string]::concat($chars) 
      } 
    } 
  } 
}

#fonction Get-OSInfo - Nécessite powershell version 2
 function Get-OSInfo
 {
    [CmdletBinding()]
    param (
      [Parameter(Mandatory=$False, ValueFromPipeline=$true)]
      [String[]]$ComputerName = '.'
    )

    Process
    {
      foreach ($computer in $ComputerName)
      {
         $infos = Get-WmiObject Win32_OperatingSystem -ComputerName $Computer
    
         $infos | Select-Object -property @{Name='ComputerName'; Expression = {$_.Csname}},
             @{Name='OS'; Expression = {$_.caption}},
             @{Name='ServicePack'; Expression = {$_.csdversion}},
             @{Name='InstallationDate'; Expression ={[system.Management.ManagementDateTimeConverter]::ToDateTime($_.Installdate)}}
      }
    }                                  
 } 

 #Fin des fonctions

#Récupération des rôles dans le domaine
$dom = [System.DirectoryServices.ActiveDirectory.Domain]::getcurrentdomain()

$domaine = $dom | fl -Property name

#Récupération du nom de domaine
$file = new-item "c:\temp\domainetemp.csv" -force -itemType File

$domaine >> $file
$ldap = Get-Content -path "c:\temp\domainetemp.csv"

$nom_du_domaine = $ldap.replace('Name : ','')
$chemtrav = "c:\" + $nom_du_domaine
$chemtrav = $chemtrav.replace(' ','')
New-Item $chemtrav -ItemType directory 
cd $chemtrav
move-item "c:\temp\domainetemp.csv" -Destination ".\nom du domaine.csv"

New-Item -Name dhcp -ItemType directory
New-Item -Name dns -ItemType directory
New-Item -Name ad -ItemType directory
New-Item -Name "ad\Utisateurs par OU(s)" -ItemType directory
New-Item -Name "ad\Ordinateurs par OU(s)" -ItemType directory
New-Item -Name "ad\Groupe(s) par OU(s)" -ItemType directory
New-Item -Name "ad\Serveur(s)" -ItemType directory
New-Item -Name "ad\Controleurs de domaine" -ItemType directory
New-Item -Name "ad\Serveur(s)\serveur(s) Hyper-V.txt" -ItemType file

$fichhyp = $chemtrav + "\ad\Serveur(s)\serveur(s) Hyper-V.txt"
$fichdc =  $chemtrav + "\ad\Controleurs de domaine\DCs.csv"
$fsmo = $chemtrav + "\ad\Controleurs de domaine\fsmo.csv"
$listsites = $chemtrav + "\ad\sites.txt"
$fichrelat = $chemtrav + "\ad\Controleurs de domaine\Relations d'approbation.txt"

# variable nom ldap du domaine
$ldapdom = "dc=" + $nom_du_domaine
$ldapdom = $ldapdom.Replace('.',',dc=')
$ldapdom = $ldapdom.Replace(' ','')

#ou
$fichier = ".\ad\OUs de  " + $nom_du_domaine +".txt"
$fichier = $fichier.replace('   ','')
$fichier = $fichier.replace('  ',' ')
Get-ADOrganizationalUnit -Filter * | ft -property DistinguishedName > $fichier
"CN=Builtin," + $ldapdom >> $fichier
"CN=Computers," + $ldapdom >> $fichier
"CN=Users,"  + $ldapdom >> $fichier
"CN=Managed Service Accounts,"  + $ldapdom >> $fichier
$fichierB = get-content $fichier | where {$_ -match "OU" -or $_ -match "CN"}

#Poste(s) du domaine

$postes = ".\ad\postes.csv"
$postes = $postes.replace('   ','')
$postes = $postes.replace('  ',' ')
Get-ADComputer -Filter * | Select-Object -Property DNSHostName | ConvertTo-Csv -delimiter "`t" | out-file -FilePath $postes

# postes connectés

$serveurs = Import-Csv $postes -delimiter "`t"
foreach ($serveur in $serveurs)
{
$FichierD = "ad\Serveur(s)\roles & fonctionnalités de " + $serveur.dnshostname + ".txt"
$FichierD = $FichierD.replace('   ','')
$FichierD = $FichierD.replace('  ',' ')

$connectes = $chemtrav + "\Poste(s) connecté(s).csv"
$ping1 = Test-Connection $serveur.DNSHostName -count 1 
$ping2 = Test-Connection $serveur.DNSHostName -count 1 -Quiet

if ($ping2 = "True") {$ping1 | ft -autosize >> $connectes }
}

$fichierf = get-content $connectes | where {$_ -match "32"}
$fichierf -replace '\s+', ' ' > $connectes
$source = get-content $connectes
"source destination ipv4 ipv6 taille 32ms" > $connectes
$source >> $connectes

$serveurs = Import-Csv $connectes -delimiter " "

$Miccons = "Poste(s) Microsoft connecté(s).txt"
$Miccons = $Miccons.replace('   ','')
$Miccons = $Miccons.replace('  ',' ')

$MicServcons = "Serveur(s) Microsoft connecté(s).csv"
$MicServcons = $MicServcons.replace('   ','')
$MicServcons = $MicServcons.replace('  ',' ')

foreach ($serveur in $serveurs)
{
$testport = Scan-Ports $serveur.destination 135
if ($testport.GetValue(1) -notmatch "non") {$serveur.destination >> $Miccons}
}

$srvs = Get-content $Miccons
Foreach ($srv in $srvs)
{
Get-OSInfo $srv | where {$_.os -match "server"} >> $MicServcons
}
$fichierh = get-content $MicServcons | where {$_ -match "server"}
$fichierh -replace '\s+', ' ' > $MicServcons
$sourcesvr = get-content $MicServcons
"ComputerName OS ServicePack InstallationDate" > $MicServcons
$sourcesvr >> $MicServcons

$disk = "ad\Serveur(s)\espace disque.txt"
$disk = $disk.replace('   ','')
$disk = $disk.replace('  ',' ')

$posmics = import-csv -Delimiter " " $MicServcons
foreach ($posmic in $posmics)

{
$FichierD = "ad\Serveur(s)\roles & fonctionnalités de " + $posmic.ComputerName + ".txt"
$FichierD = $FichierD.replace('   ','')
$FichierD = $FichierD.replace('  ',' ')
Get-WindowsFeature -ComputerName $posmic.ComputerName > $fichierd
gwmi win32_logicaldisk -filter "DriveType=3" -computer $posmic.ComputerName | format-table @{l="Nom";e={$_.__Server}}, @{l="Volume";e={$_.DeviceId}},@{l="Total (Mo)";e={[math]::round($_.Size/1MB)}},  @{l="Libre (Mo)";e={[math]::round($_.FreeSpace/1MB)}} -a >> $disk
$hyp = Get-WMIObject -ComputerName $posmic.ComputerName -namespace root\cimv2 -class Win32_ServerFeature | where {$_.id -eq '20'}
$hyp.PSComputerName  >> $fichhyp
}

#Serveurs Hyper-V
if ($fichhyp.Length -ge 0)
{
New-Item -Name "ad\Serveur(s)\Serveur(s) Hyper-V" -ItemType directory
$servhyps = Get-Content $fichhyp
foreach ($servhyp in $servhyps)
{
# Création du Fichier pour le serveur Hyper-V analysé
$FichierD = "ad\Serveur(s)\Serveur(s) Hyper-V\" + $servhyp + ".txt"
$FichierD = $FichierD.replace('   ','')
$FichierD = $FichierD.replace('  ',' ')

#Requêtage sur le serveur Hyper-v
$ListofVMs = get-wmiobject -ComputerName $servhyp -namespace root\virtualization\v2 Msvm_ComputerSystem -filter  "ElementName <> Name"
$mem = Get-WmiObject -ComputerName $servhyp -Class Win32_ComputerSystem
"Liste des machines virtuelles hébergée(s)sur le serveur hôte " + $servhyp + ":">> $FichierD
"" >> $fichierd
$ListofVMs.elementname >> $FichierD
"" >> $fichierd
"CONFIGURATION MATERIEL" >> $FichierD
"" >> $fichierd
# Mémoire installée en Mo
$memtot = $mem.TotalPhysicalMemory /1048576
"Mémoire installée: " + [int]$memtot + " Mo" >> $FichierD
"" >> $fichierd

# Mémoire libre en Mo
$memdispo = Get-Counter -ComputerName $servhyp -Counter '\Mémoire\Mégaoctets disponibles'
$memdispomb = $memdispo.CounterSamples
$memlib = $memdispomb.cookedvalue
"Mémoire disponible: " + $memlib +" Mo">> $FichierD
"" >> $fichierd

# Mémoire cache
"Mémoire cache présente:" >> $fichierd
Get-WmiObject -ComputerName $servhyp -Class win32_cachememory | ft -AutoSize >> $FichierD

"" >> $fichierd

#Analyse des disques dur
"ANALYSE DES DISQUES DUR" >> $fichierd
foreach($volume IN gwmi -Class win32_volume)  
 { 
     [int]$Capacity = $volume.capacity/1073741824;  
     [int]$freeSpace= $volume.freespace/1073741824;  
     [int]$used = $Capacity - $freeSpace;  
"Volume: " + $volume.Name + " - Capacité: " + $Capacity + " Go - Espace libre: " + $freespace + " Go - Espace utilisé: " + $used + " Go." >> $fichierd
 }

 "" >> $fichierd

"BILAN GENERAL" >> $fichierd

# Analyse général
$memdispo = Get-Counter -ComputerName $servhyp 
$memdispo.CounterSamples >> $FichierD
"" >> $fichierd
}
}

# Controleurs de domaine
Get-ADDomainController | Select-Object -Property hostname, ipv4address, ipv6address, site | ConvertTo-Csv -delimiter "`t" | out-file -FilePath $fichdc
$forest = [system.directoryservices.activedirectory.Forest]::GetCurrentForest()
$forest.Sites > $listsites
$DomainInfo = [System.DirectoryServices.ActiveDirectory.Domain]::GetCurrentDomain()
$RelationShip = $DomainInfo.GetAllTrustRelationships()
$RelationShip > $fichrelat

Get-FSMORoleOwner | ConvertTo-Csv -delimiter "`t" | out-file -FilePath $fsmo

#ordinateurs
$Now = Get-Date
$LastWrite = $Now.AddDays(-1)
$ous = $fichierb
foreach ($ou in $fichierB)
{
$fichierA = "ad\Ordinateurs par OU(s)\" + $ou + ".csv"
$fichierA = $fichierA.replace('   ','')
$fichierA = $fichierA.replace('  ',' ')
Get-ADComputer -Filter * -SearchBase $ou | Select-Object -Property DNSHostName | ConvertTo-Csv -delimiter "`t" | out-file -FilePath $fichierA
}

foreach ($posmic in $posmics)
{
$dossierB = "ad\serveur(s)\" + $posmic.computername
$dossierB = $dossierB.replace('   ','')
$dossierB = $dossierB.replace('  ',' ')
New-Item -Name $dossierB -ItemType directory

$fichierG = $dossierB + "\Installation.csv"
$fichierG = $fichierG.replace('   ','')
$fichierG = $fichierG.replace('  ',' ')
Get-WinEvent -ComputerName $posmic.computername setup -ErrorAction SilentlyContinue -MaxEvents 100| where {$_.leveldisplayname -eq "erreur" -or $_.leveldisplayname -eq "critique" -and $_.timecreated -ge $date} -WarningAction Continue | ConvertTo-Csv -delimiter "`t" | out-file -FilePath $fichierG

$fichierG = $dossierB + "\Sécurité.csv"
$fichierG = $fichierG.replace('   ','')
$fichierG = $fichierG.replace('  ',' ')
Get-WinEvent -ComputerName $posmic.computername Security -ErrorAction SilentlyContinue -MaxEvents 100 | ConvertTo-Csv -delimiter "`t" | out-file -FilePath $fichierG

$fichierG = $dossierB + "\Application.csv"
$fichierG = $fichierG.replace('   ','')
$fichierG = $fichierG.replace('  ',' ')
Get-WinEvent -ComputerName $posmic.computername Application -ErrorAction SilentlyContinue -MaxEvents 100 | where {$_.leveldisplayname -eq "erreur" -or $_.leveldisplayname -eq "critique" -and $_.timecreated -ge $date} -ErrorAction Continue | ConvertTo-Csv -delimiter "`t" | out-file -FilePath $fichierG

$fichierG = $dossierB + "\Système.csv"
$fichierG = $fichierG.replace('   ','')
$fichierG = $fichierG.replace('  ',' ')
Get-WinEvent -ComputerName $posmic.computername System -ErrorAction SilentlyContinue -MaxEvents 100 | where {$_.leveldisplayname -eq "erreur" -or $_.leveldisplayname -eq "critique" -and $_.timecreated -ge $date} -WarningAction Continue -ErrorAction SilentlyContinue | ConvertTo-Csv -delimiter "`t" | out-file -FilePath $fichierG
}

#Utilisateurs
foreach ($ou in $ous)
{
$fichierA = "ad\Utisateurs par OU(s)\" + $ou + ".csv"
$fichierA = $fichierA.replace('   ','')
$fichierA = $fichierA.replace('  ',' ')
Get-ADuser -Filter * -SearchBase $ou | Select-Object -Property Name,GivenName,SamAccountName,SurName | ConvertTo-Csv -delimiter "`t" | out-file -FilePath $fichierA
}

#Groupes
foreach ($ou in $ous)
{
$fichierA = "ad\Groupe(s) par OU(s)\" + $ou + ".csv"
$fichierA = $fichierA.replace('   ','')
$fichierA = $fichierA.replace('  ',' ')
Get-ADgroup -Filter * -SearchBase $ou | Select-Object -Property Name,GroupCategory | ConvertTo-Csv -delimiter "`t" | out-file -FilePath $fichierA

#Membres de

$memberofs = import-csv $fichiera -delimiter "`t"
foreach ($memberof in $memberofs)
{
$fichierc = "ad\Groupe(s) par OU(s)\Membre du groupe " + $memberof.name +".csv"
$fichierc = $fichierc.replace('   ','')
$fichierc = $fichierc.replace('  ',' ')
Get-ADGroupMember $memberof.name | Select-Object -Property name,distinguishedName | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichierc
}
}

# SERVEURS DHCP

$fichier = ".\dhcp\DHCPs du domaine" + $nom_du_domaine +".csv"
$fichier = $fichier.replace('   ','')
$fichier = $fichier.replace('  ',' ')

Get-DhcpServerInDC | Select-Object -Property IPAddress,dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier
$servers = Import-Csv $fichier -delimiter "`t"
foreach ($server in $servers)
{
$dossier = ".\dhcp\" + $server.dnsname
New-Item -Name $dossier -ItemType directory

$fichier = $dossier+"\Etendue(s) du serveur DHCP v4 " + $server.dnsname +".csv"
$fichier = $fichier.replace('   ','')
$fichier = $fichier.replace('  ',' ')
Get-DhcpServerv4Scope -computername $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier


$etendues = Import-Csv $fichier -delimiter "`t"
foreach ($etendue in $etendues)
{
$fichier2 = ".\dhcp\"+ $server.dnsname +"\Liste des reservations de l'etendue " + $etendue.ScopeId + "  du serveur DHCP v4 " + $server.dnsname +".csv"
$fichier2 = $fichier2.replace('   ','')
$fichier2 = $fichier2.replace('  ',' ')

Get-DhcpServerv4Reservation -ScopeId $etendue.ScopeId -ComputerName $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier2
}

$etendues = Import-Csv $fichier -delimiter "`t"
foreach ($etendue in $etendues)
{
$fichier2 = ".\dhcp\"+ $server.dnsname +"\Liste IPs délivrées de l'etendue " + $etendue.ScopeId + "  du serveur DHCP v4 " + $server.dnsname +".csv"
$fichier2 = $fichier2.replace('   ','')
$fichier2 = $fichier2.replace('  ',' ')

Get-DhcpServerv4Lease -ScopeId $etendue.ScopeId -ComputerName $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier2
}

$etendues = Import-Csv $fichier -delimiter "`t"
foreach ($etendue in $etendues)
{
$fichier2 = ".\dhcp\"+ $server.dnsname +"\Statistiques de l'etendue " + $etendue.ScopeId + "  du serveur DHCP v4 " + $server.dnsname +".csv"
$fichier2 = $fichier2.replace('   ','')
$fichier2 = $fichier2.replace('  ',' ')

Get-DhcpServerv4ScopeStatistics -ScopeId $etendue.ScopeId -ComputerName $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier2
}


$fichier = $dossier+"\Paramètres du serveur DHCP v4 " + $server.dnsname +".csv"
$fichier = $fichier.replace('   ','')
$fichier = $fichier.replace('  ',' ')
Get-DhcpServerv4DnsSetting -ComputerName $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier

$fichier = $dossier+"\FailOver du serveur DHCP v4 " + $server.dnsname +".csv"
$fichier = $fichier.replace('   ','')
$fichier = $fichier.replace('  ',' ')
Get-DhcpServerv4Failover -ComputerName $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier

$fichier = $dossier+"\Classe du serveur DHCP v4 " + $server.dnsname +".csv"
$fichier = $fichier.replace('   ','')
$fichier = $fichier.replace('  ',' ')
Get-DhcpServerv4Class -ComputerName $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier

$fichier = $dossier+"\Classe du serveur DHCP v4 " + $server.dnsname +".csv"
$fichier = $fichier.replace('   ','')
$fichier = $fichier.replace('  ',' ')
Get-DhcpServerv4Filter -ComputerName $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier

$fichier = $dossier+"\Liste des filtres du serveur DHCP v4 " + $server.dnsname +".csv"
$fichier = $fichier.replace('   ','')
$fichier = $fichier.replace('  ',' ')
Get-DhcpServerv4FilterList -ComputerName $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier

$fichier = $dossier+"\Liste des options du serveur DHCP v4 " + $server.dnsname +".csv"
$fichier = $fichier.replace('   ','')
$fichier = $fichier.replace('  ',' ')
Get-DhcpServerv4OptionValue -ComputerName $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier

$fichier = $dossier+"\Liste des stratégies du serveur DHCP v4 " + $server.dnsname +".csv"
$fichier = $fichier.replace('   ','')
$fichier = $fichier.replace('  ',' ')
Get-DhcpServerv4Policy -ComputerName $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier

$fichier = $dossier+"\Statistiques du serveur DHCP v4 " + $server.dnsname +".csv"
$fichier = $fichier.replace('   ','')
$fichier = $fichier.replace('  ',' ')
Get-DhcpServerv4Statistics -ComputerName $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier

$fichier = $dossier+"\Etendue(s) du serveur DHCP v6 " + $server.dnsname +".csv"
$fichier = $fichier.replace('   ','')
$fichier = $fichier.replace('  ',' ')
Get-DhcpServerv6Scope -computername $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier


$etendues = Import-Csv $fichier -delimiter "`t"
foreach ($etendue in $etendues)
{
$fichier2 = ".\dhcp\"+ $server.dnsname +"\Liste des reservations de l'etendue " + $etendue.ScopeId + "  du serveur DHCP v6 " + $server.dnsname +".csv"
$fichier2 = $fichier2.replace('   ','')
$fichier2 = $fichier2.replace('  ',' ')

Get-DhcpServerv6Reservation -ScopeId $etendue.ScopeId -ComputerName $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier2
}

$etendues = Import-Csv $fichier -delimiter "`t"
foreach ($etendue in $etendues)
{
$fichier2 = ".\dhcp\"+ $server.dnsname +"\Liste IPs délivrées de l'etendue " + $etendue.ScopeId + "  du serveur DHCP v6 " + $server.dnsname +".csv"
$fichier2 = $fichier2.replace('   ','')
$fichier2 = $fichier2.replace('  ',' ')

Get-DhcpServerv6Lease -ScopeId $etendue.ScopeId -ComputerName $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier2
}

$etendues = Import-Csv $fichier -delimiter "`t"
foreach ($etendue in $etendues)
{
$fichier2 = ".\dhcp\"+ $server.dnsname +"\Statistiques de l'etendue " + $etendue.ScopeId + "  du serveur DHCP v6 " + $server.dnsname +".csv"
$fichier2 = $fichier2.replace('   ','')
$fichier2 = $fichier2.replace('  ',' ')

Get-DhcpServerv6ScopeStatistics -ScopeId $etendue.ScopeId -ComputerName $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier2
}

$fichier = $dossier+"\Paramètres du serveur DHCP v6 " + $server.dnsname +".csv"
$fichier = $fichier.replace('   ','')
$fichier = $fichier.replace('  ',' ')
Get-DhcpServerv6DnsSetting -ComputerName $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier

$fichier = $dossier+"\Classe du serveur DHCP v6 " + $server.dnsname +".csv"
$fichier = $fichier.replace('   ','')
$fichier = $fichier.replace('  ',' ')
Get-DhcpServerv6Class -ComputerName $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier

$fichier = $dossier+"\Liste des options du serveur DHCP v6 " + $server.dnsname +".csv"
$fichier = $fichier.replace('   ','')
$fichier = $fichier.replace('  ',' ')
Get-DhcpServerv6OptionValue -ComputerName $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier

$fichier = $dossier+"\Statistiques du serveur DHCP v6 " + $server.dnsname +".csv"
$fichier = $fichier.replace('   ','')
$fichier = $fichier.replace('  ',' ')
Get-DhcpServerv6Statistics -ComputerName $server.dnsname | ConvertTo-Csv -delimiter "`t"| out-file -FilePath $fichier
}

# SERVEURS DNS

$fichiers = ".\dns\Liste des Serveur(s) DNS" + $nom_du_domaine +".txt"
$fichiers = $fichiers.replace('   ','')
$fichiers = $fichiers.replace('  ',' ')

$fichier1 = ".\dns\TEMP-DNS.txt"
$fichier1 = $fichier1.replace('   ','')
$fichier1 = $fichier1.replace('  ',' ')

$NICs = Get-WMIObject Win32_NetworkAdapterConfiguration -computername . | where {$_.IPEnabled -eq $true}
$serverdns = $nics.DNSServerSearchOrder | Select-Object -First 1

$DNSZone = ([System.DirectoryServices.ActiveDirectory.Domain]::getcurrentdomain()).Name
$Record = Get-WMIObject -Computer $serverdns ` -Namespace "root\MicrosoftDNS" -Class "MicrosoftDNS_nsType" ` -Filter "ContainerName='$DNSZone'"
$Record.dnsservername > $fichier1
Get-Content $fichier1 | Get-Unique | OUT-FILE $fichiers
Remove-Item $fichier1

$dossiers = get-content $fichiers 
foreach ($dossier in $dossiers)
{
$fichier1 = "dns\" + $dossier
$fichier1 = $fichier1.replace('   ','')
$fichier1 = $fichier1.replace('  ',' ')
New-Item -Name $fichier1 -ItemType directory

$fichier2 = $fichier1 + "\Paramètres du serveur DNS.txt"
Get-DnsServer -ComputerName $dossier > $fichier2

$fichier2 = $fichier1 + "\Liste rouge.txt"
Get-DnsServerGlobalQueryBlockList -ComputerName $dossier > $fichier2

$fichier2 = $fichier1 + "\zone(s) dns.txt"
Get-DnsServerzone -ComputerName $dossier > $fichier2

$fichier2 = $fichier1 + "\zone(s) dns.csv"
Get-DnsServerzone -ComputerName $dossier | ConvertTo-Csv -delimiter "`t" | out-file -FilePath $fichier2

$fichier2 = $fichier1 + "\statistiques.txt"
Get-DnsServerStatistics -ComputerName $dossier > $fichier2
}

#recuperation des gpos

 
 Get-GPO -domain ([System.DirectoryServices.ActiveDirectory.Domain]::getcurrentdomain()).Name

 move-item -Path 'C:\temp\Rapports GPOs' -Destination $chemtrav
 remove-item -Path c:\temp -Recurse

 Get-ChildItem .\ -recurse | Where-Object -FilterScript {($_.length -le 0)} | Remove-Item
 ls -recurse | where {!@(ls -force $_.fullname)} | rm
 

 function Compress-ToZip
{
    param([string]$zipfilename)

    if(-not (test-path($zipfilename)))
    {
        set-content $zipfilename ("PK" + [char]5 + [char]6 + ("$([char]0)" * 18))
        (Get-ChildItem $zipfilename).IsReadOnly = $false    
    }
        
    $shellApplication = new-object -com shell.application
    $zipPackage = $shellApplication.NameSpace($zipfilename)
        
    foreach($file in $input) 
    { 
         $zipPackage.CopyHere($file.FullName)
         Start-sleep -milliseconds 500
    }
}

while (Test-Path "c:\rapport") { remove-item "c:\rapport" -Recurse -force} 

cd c:\
New-Item -Name "rapport" -ItemType directory
$fichierzip = "c:\" + $nom_du_domaine +".zip"
$fichierzip = $fichierzip.replace('   ','')
$fichierzip = $fichierzip.replace('  ','')
$dossier = "c:\" + $nom_du_domaine
$dossier = $dossier.replace('   ','')
$dossier = $dossier.replace('  ','')

#Mise en conformité le nom des fichiers pour zipper
$dossiergr = $dossier + "\ad\Groupe(s) par OU(s)"
$dossieror = $dossier + "\ad\Ordinateurs par OU(s)"
$dossierus = $dossier + "\ad\Utisateurs par OU(s)"
cd $dossiergr
Get-ChildItem | ForEach-Object { Rename-Item $_ ($_.Name -replace "’"," ")}
cd $dossieror
Get-ChildItem | ForEach-Object { Rename-Item $_ ($_.Name -replace "’"," ")}
cd $dossierus
Get-ChildItem | ForEach-Object { Rename-Item $_ ($_.Name -replace "’"," ")}

#compression du rapport

Get-Item $dossier | Compress-ToZip "c:\rapport\Rapport sur le domaine audite.zip" -force

Show-MessageBox

Remove-Item $dossier -recurse -Force
